pareidolia package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pareidolia.cli

Submodules
----------

pareidolia.detection module
---------------------------

.. automodule:: pareidolia.detection
   :members:
   :undoc-members:
   :show-inheritance:

pareidolia.hic\_utils module
----------------------------

.. automodule:: pareidolia.hic_utils
   :members:
   :undoc-members:
   :show-inheritance:

pareidolia.io module
--------------------

.. automodule:: pareidolia.io
   :members:
   :undoc-members:
   :show-inheritance:

pareidolia.preprocess module
----------------------------

.. automodule:: pareidolia.preprocess
   :members:
   :undoc-members:
   :show-inheritance:

pareidolia.stats module
-----------------------

.. automodule:: pareidolia.stats
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pareidolia
   :members:
   :undoc-members:
   :show-inheritance:
